@@ -32,11 +32,13 @@ class CaseImportChecker(BaseChecker):
         self._check_import_stack = []
 
     def _check_import(self, node: nodes.Import):
+        print(node.names[0][0])
+        print(node.names[0][1])
         if node.names[0][0] == "pyspark.sql.function" and node.names[0][1] == 'f':
             self.add_message(
                 "lower-case-function-import", node=node
             )
-        if node.names[0][0] == "pyspark.sql.types" and node.names[0][1] == 't':
+        elif node.names[0][0] == "pyspark.sql.types" and node.names[0][1] == 't':
             self.add_message(
                 "lower-case-type-import", node=node
             )
